==> auntie-0.14.1.tgz: package/example/auntie-collect-results-example.js <==
/*
 * Auntie example for collecting results, it loads a file containing 8192
 * long english words, separated by CRLF '\r\n' pattern.
 */

const log = console.log
    , fs = require( 'fs' )
    , Auntie = require( '../' )
    , stdout = process.stdout
    , dpath = __dirname + '/long-english-words.txt'
    , pattern = '\r\n'
    // default pattern is '\r\n'
    , untie = Auntie( pattern )
    , rstream = fs.createReadStream( dpath )
    ;

log();
log( '- Auntie example, loading english long words from file:\n "%s"', dpath );
log( '\n- original stream highwatermark value: %d bytes', rstream._readableState.highWaterMark );

// I voluntarily reduce the chunk buffer size to 512 bytes
rstream._readableState.highWaterMark = 512;

log( '- new stream highwatermark value: %d bytes', rstream._readableState.highWaterMark );

let t = 0
    , c = 0
    , m = 0
    ;

log( '\n - read stream..' );

rstream.on( 'data', function ( chunk ) {
    log( '\n -> data chunk %d received\n', ++c );
    t += chunk.length;
    // concat current results to collected array
    let curr = untie.do( chunk, true )
        ;
    if ( curr.length ) {
        let el = curr[ 0 ]
            , i = 0
            ;
        for ( ; i < curr.length; el = curr[ ++i ] ) {
            ++m;
            log(' !snap (%d) -> (%d) %s', m, el.length, el );
        }
    }
} );

rstream.on( 'end', function () {
    log( '\n !end' );
} );

rstream.on( 'close', function () {
    log( ' !close' );
    log();
    log( '- total data chunks: %d ', c );
    log( '- total data length: %d bytes', t );
    log( '- current pattern (%d):', pattern.length, untie.pattern.slice( 0, 255 ) );
    log( '- total matches: %d', m );
    log();

} );

==> auntie-0.17.3.tgz: package/example/auntie-collect-results-example.js <==
/*
 * Auntie example for collecting results, it loads a file containing 8192
 * long english words, separated by CRLF '\r\n' pattern.
 */

const log = console.log
    , fs = require( 'fs' )
    , Auntie = require( '../' )
    , stdout = process.stdout
    , dpath = __dirname + '/long-english-words.txt'
    , pattern = '\r\n'
    // default pattern is '\r\n'
    , untie = Auntie( pattern )
    , rstream = fs.createReadStream( dpath )
    ;

log();
log( '- Auntie example, loading english long words from file:\n "%s"', dpath );
log( '\n- original stream highwatermark value: %d bytes', rstream._readableState.highWaterMark );

// I voluntarily reduce the chunk buffer size to 512 bytes
rstream._readableState.highWaterMark = 512;

log( '- new stream highwatermark value: %d bytes', rstream._readableState.highWaterMark );

let t = 0
    , c = 0
    , m = 0
    ;

log( '\n - read stream..' );

rstream.on( 'data', function ( chunk ) {
    log( '\n -> data chunk %d received\n', ++c );
    t += chunk.length;
    // concat current results to collected array
    let curr = untie.do( chunk, true )
        ;
    if ( curr.length ) {
        let el = curr[ 0 ]
            , i = 0
            ;
        for ( ; i < curr.length; el = curr[ ++i ] ) {
            ++m;
            log(' !snap (%d) -> (%d) %s', m, el.length, el );
        }
    }
} );

rstream.on( 'end', function () {
    log( '\n !end' );
} );

rstream.on( 'close', function () {
    log( ' !close' );
    log();
    log( '- total data chunks: %d ', c );
    log( '- total data length: %d bytes', t );
    log( '- current pattern (%d):', pattern.length, untie.seq );
    log( '- total matches: %d', m );
    log();

} );
